@@ -1,4 +1,4 @@
-#!/usr/bin/perl 
+#!/usr/bin/env perl
 use strict;
 use warnings;
 use IO::Async;
@@ -13,25 +13,17 @@ use Tickit::Widget::Static;
 my $tickit = Tickit::Async->new;
 my $top = Tickit::Widget::Progressbar::Horizontal->new(
 	completion	=> 0,
-	bg		=> 4,
-	fg		=> 2,
 );
 my $bottom = Tickit::Widget::Progressbar::Horizontal->new(
 	completion	=> 0,
 	direction	=> 1,
-	bg		=> 4,
-	fg		=> 2,
 );
 my $left = Tickit::Widget::Progressbar::Vertical->new(
 	completion	=> 0,
-	bg		=> 4,
-	fg		=> 2,
 );
 my $right = Tickit::Widget::Progressbar::Vertical->new(
 	completion	=> 0,
 	direction	=> 1,
-	bg		=> 4,
-	fg		=> 2,
 );
 my @bars = ($left, $top, $right, $bottom);
 
@@ -55,7 +47,7 @@ my $timer = IO::Async::Timer::Periodic->new(
 	interval => 0.1,
 
 	on_tick => sub {
-		$_->completion($completion += 0.0005) for @bars;
+		$_->completion($completion += 0.0002) for @bars;
 		$loop->later(sub { $loop->loop_stop }) if $completion >= 1.00;
 	},
 );
